# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))


# -- Project information -----------------------------------------------------

project = "shiny-k8s"
copyright = "2023, Bioinformatics and Biostatistics Hub, Institut Pasteur"
author = "Bioinformatics and Biostatistics Hub, Institut Pasteur"


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "sphinx.ext.autosummary",
    "sphinx.ext.autodoc",
    "sphinx.ext.intersphinx",
    "sphinx.ext.coverage",
    "sphinx.ext.viewcode",
    "sphinx.ext.graphviz",
    'sphinx_copybutton',
    'sphinx_code_tabs'
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "sphinx_rtd_theme"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]

# -- Extension configuration -------------------------------------------------

# -- Options for intersphinx extension ---------------------------------------

# Example configuration for intersphinx: refer to the Python standard library.
# intersphinx_mapping = {"https://docs.python.org/": None}

# -- Extension configuration -------------------------------------------------i

autoclass_content = "both"  # include both class docstring and __init__
autodoc_default_flags = [
    # Make sure that any autodoc declarations show the right members
    "members",
    "private-members",
    "show-inheritance",
]
autosummary_generate = True  # Make _autosummary files and include them
napoleon_numpy_docstring = False  # Force consistency, leave only Google
napoleon_use_rtype = False  # More legible

# The suffix of source filenames.
autosummary_generate = True
exclude_patterns = ["_build"]

html_context = {
    "display_gitlab": True,  # Integrate Gitlab
    "gitlab_user": "hub",  # Username
    "gitlab_host": "gitlab.pasteur.fr",
    "gitlab_repo": "shiny-k8s",  # Repo name
    "gitlab_version": "docs",  # Branch name
    "conf_py_path": "/source/",  # Path in the checkout to the docs root
}

html_theme_options = {
    'prev_next_buttons_location': 'bottom',
    'navigation_depth': 5,
}

html_css_files = [
    'theme_overrides.css',
]

# do not try to import tkinter for sphinx
autodoc_mock_imports = ["_tkinter"]
